@@ -1,7 +1,7 @@
 """
 Type annotations for appflow service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/literals.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appflow/literals/)
 
 Usage::
 
@@ -60,6 +60,7 @@ __all__ = (
     "AppflowServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "RegionName",
 )
 
 
@@ -546,6 +547,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -743,3 +745,21 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+RegionName = Literal[
+    "af-south-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
